# Copyright 2020, Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

package Google::Ads::GoogleAds::V23::Enums::SearchTermMatchSourceEnum;

use strict;
use warnings;

use Const::Exporter enums => [
  UNSPECIFIED                 => "UNSPECIFIED",
  UNKNOWN                     => "UNKNOWN",
  ADVERTISER_PROVIDED_KEYWORD => "ADVERTISER_PROVIDED_KEYWORD",
  AI_MAX_KEYWORDLESS          => "AI_MAX_KEYWORDLESS",
  AI_MAX_BROAD_MATCH          => "AI_MAX_BROAD_MATCH",
  DYNAMIC_SEARCH_ADS          => "DYNAMIC_SEARCH_ADS",
  PERFORMANCE_MAX             => "PERFORMANCE_MAX",
  VERTICAL_ADS_DATA_FEED      => "VERTICAL_ADS_DATA_FEED"
];

1;
